@@ -408,23 +408,26 @@ void OperationStack::push(Operation* o)
 {
     Q_ASSERT(o);
 
-    foreach(Operation * currentOp, operations()) {
-        if (mergeNewOperation(currentOp, o))
+    auto currentOp = operations().end();
+    while (currentOp != operations().begin())
+    {
+        --currentOp;
+        if (mergeNewOperation(*currentOp, o))
             break;
 
-        if (mergeCopyOperation(currentOp, o))
+        if (mergeCopyOperation(*currentOp, o))
             break;
 
-        if (mergeRestoreOperation(currentOp, o))
+        if (mergeRestoreOperation(*currentOp, o))
             break;
 
-        if (mergePartFlagsOperation(currentOp, o))
+        if (mergePartFlagsOperation(*currentOp, o))
             break;
 
-        if (mergePartLabelOperation(currentOp, o))
+        if (mergePartLabelOperation(*currentOp, o))
             break;
 
-        if (mergeCreatePartitionTableOperation(currentOp, o))
+        if (mergeCreatePartitionTableOperation(*currentOp, o))
             break;
     }
 
@@ -449,6 +452,29 @@ void OperationStack::pop()
     emit operationsChanged();
 }
 
+/** Check whether previous operations involve given partition.
+
+    @param p Pointer to the Partition. Must not be nullptr.
+*/
+bool OperationStack::contains(const Partition* p) const
+{
+    Q_ASSERT(p);
+
+    foreach(Operation * o, operations()) {
+        if (o->targets(*p))
+            return true;
+
+        CopyOperation* copyOp = dynamic_cast<CopyOperation*>(o);
+        if (copyOp) {
+            const Partition* source = &copyOp->sourcePartition();
+            if (source == p)
+                return true;
+        }
+    }
+
+    return false;
+}
+
 /** Removes all Operations from the OperationStack, calling Operation::undo() on them and deleting them. */
 void OperationStack::clearOperations()
 {
