@@ -1,5 +1,6 @@
 /*************************************************************************
  *  Copyright (C) 2008 by Volker Lanz <vl@fidra.de>                      *
+ *  Copyright (C) 2015 by Teo Mrnjavac <teo@kde.org>                     *
  *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
  *                                                                       *
  *  This program is free software; you can redistribute it and/or        *
@@ -26,9 +27,10 @@
 #include "util/externalcommand.h"
 #include "util/report.h"
 
+#include <QDebug>
+#include <QRegularExpression>
 #include <QString>
 #include <QStringList>
-#include <QDebug>
 
 #include <KLocalizedString>
 #include <KIOCore/KMountPoint>
@@ -79,7 +81,8 @@ Partition::~Partition()
     // list of children). As a workaround, always remove a partition from its parent here in the dtor.
     // This presumably fixes 232092, but backporting is too risky until we're sure this doesn't cause
     // side-effects.
-    parent()->remove(this);
+    if (m_Parent)
+        parent()->remove(this);
     clearChildren();
     deleteFileSystem();
 }
@@ -186,6 +189,8 @@ qint64 Partition::sectorsUsed() const
 /** @return the minimum number of sectors this Partition must be long */
 qint64 Partition::minimumSectors() const
 {
+    if (roles().has(PartitionRole::Luks))
+        return fileSystem().minCapacity() / sectorSize() + 4096; // 4096 is the default cryptsetup payload offset
     return fileSystem().minCapacity() / sectorSize();
 }
 
@@ -212,7 +217,7 @@ void Partition::adjustLogicalNumbers(qint32 deletedNumber, qint32 insertedNumber
 
     foreach(Partition * p, children()) {
         QString path = p->partitionPath();
-        path.remove(QRegExp(QStringLiteral("([0-9]+$)")));
+        path.remove(QRegularExpression(QStringLiteral("(\\d+$)")));
         if (deletedNumber > 4 && p->number() > deletedNumber)
             p->setPartitionPath(path + QString::number(p->number() - 1));
         else if (insertedNumber > 4 && p->number() >= insertedNumber)
@@ -264,16 +269,15 @@ void Partition::checkChildrenMounted()
 bool Partition::canMount() const
 {
     // cannot mount if already mounted
-    if (isMounted())
+    if (isMounted())  {
         return false;
+    }
 
-    // if the file system says we can mount without mount points, that's fine
-    // (this is the case for swap only, actually)
-    if (fileSystem().canMount(deviceNode()))
+    if (fileSystem().canMount(deviceNode(), mountPoint())) {
         return true;
+    }
 
-    // cannot mount if we have no mount points
-    return !mountPoint().isEmpty();
+    return false;
 }
 
 /** @return true if this Partition can be unmounted */
@@ -292,12 +296,8 @@ bool Partition::mount(Report& report)
 
     bool success = false;
 
-    if (fileSystem().canMount(deviceNode()))
-        success = fileSystem().mount(deviceNode());
-    else {
-        ExternalCommand mountCmd(report, QStringLiteral("mount"), QStringList() << QStringLiteral("-v") << deviceNode() << mountPoint());
-        if (mountCmd.run() && mountCmd.exitCode() == 0)
-            success = true;
+    if (fileSystem().canMount(deviceNode(), mountPoint())) {
+        success = fileSystem().mount(report, deviceNode(), mountPoint());
     }
 
     setMounted(success);
@@ -317,14 +317,7 @@ bool Partition::unmount(Report& report)
 
     while (success) {
         if (fileSystem().canUnmount(deviceNode())) {
-            success = fileSystem().unmount(deviceNode());
-            if (success)
-                setMountPoint(QString());
-        } else {
-
-            ExternalCommand umountCmd(report, QStringLiteral("umount"), QStringList() << QStringLiteral("-v") << deviceNode());
-            if (!umountCmd.run() || umountCmd.exitCode() != 0)
-                success = false;
+            success = fileSystem().unmount(report, deviceNode());
         }
 
         KMountPoint::List mountPoints = KMountPoint::currentMountPoints(KMountPoint::NeedRealDeviceName);
@@ -347,9 +340,10 @@ void Partition::deleteFileSystem()
 void Partition::setPartitionPath(const QString& s)
 {
     m_PartitionPath = s;
-    QRegExp rxPartitionNumber(QStringLiteral("([0-9]+$)"));
-    if (rxPartitionNumber.indexIn(partitionPath()) > -1) {
-        setNumber(rxPartitionNumber.cap().toInt());
+    QRegularExpression re(QStringLiteral("(\\d+$)"));
+    QRegularExpressionMatch rePartitionNumber = re.match(partitionPath());
+    if (rePartitionNumber.hasMatch()) {
+        setNumber(rePartitionNumber.captured().toInt());
         return;
     }
     setNumber(-1);
