@@ -21,8 +21,8 @@
 #include "util/externalcommand.h"
 #include "util/capacity.h"
 
+#include <QRegularExpression>
 #include <QString>
-#include <QRegExp>
 
 namespace FS
 {
@@ -50,7 +50,7 @@ void ext2::init()
     m_GetLabel = cmdSupportCore;
     m_SetLabel = findExternal(QStringLiteral("e2label")) ? cmdSupportFileSystem : cmdSupportNone;
     m_Create = findExternal(QStringLiteral("mkfs.ext2")) ? cmdSupportFileSystem : cmdSupportNone;
-    m_Check = findExternal(QStringLiteral("e2fsck"), QStringList() << QStringLiteral("-V")) ? cmdSupportFileSystem : cmdSupportNone;
+    m_Check = findExternal(QStringLiteral("e2fsck"), { QStringLiteral("-V") }) ? cmdSupportFileSystem : cmdSupportNone;
     m_UpdateUUID = findExternal(QStringLiteral("tune2fs")) ? cmdSupportFileSystem : cmdSupportNone;
     m_Grow = (m_Check != cmdSupportNone && findExternal(QStringLiteral("resize2fs"))) ? cmdSupportFileSystem : cmdSupportNone;
     m_Shrink = (m_Grow != cmdSupportNone && m_GetUsed) != cmdSupportNone ? cmdSupportFileSystem : cmdSupportNone;
@@ -94,26 +94,29 @@ qint64 ext2::maxLabelLength() const
 
 qint64 ext2::readUsedCapacity(const QString& deviceNode) const
 {
-    ExternalCommand cmd(QStringLiteral("dumpe2fs"), QStringList() << QStringLiteral("-h") << deviceNode);
+    ExternalCommand cmd(QStringLiteral("dumpe2fs"), { QStringLiteral("-h"), deviceNode });
 
     if (cmd.run()) {
         qint64 blockCount = -1;
-        QRegExp rxBlockCount(QStringLiteral("Block count:\\s*(\\d+)"));
+        QRegularExpression re(QStringLiteral("Block count:\\s+(\\d+)"));
+        QRegularExpressionMatch reBlockCount = re.match(cmd.output());
 
-        if (rxBlockCount.indexIn(cmd.output()) != -1)
-            blockCount = rxBlockCount.cap(1).toLongLong();
+        if (reBlockCount.hasMatch())
+            blockCount = reBlockCount.captured(1).toLongLong();
 
         qint64 freeBlocks = -1;
-        QRegExp rxFreeBlocks(QStringLiteral("Free blocks:\\s*(\\d+)"));
+        re.setPattern(QStringLiteral("Free blocks:\\s+(\\d+)"));
+        QRegularExpressionMatch reFreeBlocks = re.match(cmd.output());
 
-        if (rxFreeBlocks.indexIn(cmd.output()) != -1)
-            freeBlocks = rxFreeBlocks.cap(1).toLongLong();
+        if (reFreeBlocks.hasMatch())
+            freeBlocks = reFreeBlocks.captured(1).toLongLong();
 
         qint64 blockSize = -1;
-        QRegExp rxBlockSize(QStringLiteral("Block size:\\s*(\\d+)"));
+        re.setPattern(QStringLiteral("Block size:\\s+(\\d+)"));
+        QRegularExpressionMatch reBlockSize = re.match(cmd.output());
 
-        if (rxBlockSize.indexIn(cmd.output()) != -1)
-            blockSize = rxBlockSize.cap(1).toLongLong();
+        if (reBlockSize.hasMatch())
+            blockSize = reBlockSize.captured(1).toLongLong();
 
         if (blockCount > -1 && freeBlocks > -1 && blockSize > -1)
             return (blockCount - freeBlocks) * blockSize;
@@ -124,32 +127,33 @@ qint64 ext2::readUsedCapacity(const QString& deviceNode) const
 
 bool ext2::check(Report& report, const QString& deviceNode) const
 {
-    ExternalCommand cmd(report, QStringLiteral("e2fsck"), QStringList() << QStringLiteral("-f") << QStringLiteral("-y") << QStringLiteral("-v") << deviceNode);
+    ExternalCommand cmd(report, QStringLiteral("e2fsck"), { QStringLiteral("-f"), QStringLiteral("-y"), QStringLiteral("-v"), deviceNode });
     return cmd.run(-1) && (cmd.exitCode() == 0 || cmd.exitCode() == 1 || cmd.exitCode() == 2 || cmd.exitCode() == 256);
 }
 
 bool ext2::create(Report& report, const QString& deviceNode) const
 {
-    ExternalCommand cmd(report, QStringLiteral("mkfs.ext2"), QStringList() << QStringLiteral("-qF") << deviceNode);
+    ExternalCommand cmd(report, QStringLiteral("mkfs.ext2"), { QStringLiteral("-qF"), deviceNode });
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
 
 bool ext2::resize(Report& report, const QString& deviceNode, qint64 length) const
 {
     const QString len = QString::number(length / 512) + QStringLiteral("s");
-    ExternalCommand cmd(report, QStringLiteral("resize2fs"), QStringList() << deviceNode << len);
+
+    ExternalCommand cmd(report, QStringLiteral("resize2fs"), { deviceNode, len });
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
 
 bool ext2::writeLabel(Report& report, const QString& deviceNode, const QString& newLabel)
 {
-    ExternalCommand cmd(report, QStringLiteral("e2label"), QStringList() << deviceNode << newLabel);
+    ExternalCommand cmd(report, QStringLiteral("e2label"), { deviceNode, newLabel });
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
 
 bool ext2::updateUUID(Report& report, const QString& deviceNode) const
 {
-    ExternalCommand cmd(report, QStringLiteral("tune2fs"), QStringList() << QStringLiteral("-U") << QStringLiteral("random") << deviceNode);
+    ExternalCommand cmd(report, QStringLiteral("tune2fs"), { QStringLiteral("-U"), QStringLiteral("random"), deviceNode });
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
 }
