@@ -21,6 +21,7 @@
 #include "util/externalcommand.h"
 
 #include <KLocalizedString>
+#include <QDebug>
 
 namespace FS
 {
@@ -77,22 +78,23 @@ qint64 linuxswap::maxLabelLength() const
 
 bool linuxswap::create(Report& report, const QString& deviceNode) const
 {
-    ExternalCommand cmd(report, QStringLiteral("mkswap"), QStringList() << deviceNode);
+    ExternalCommand cmd(report, QStringLiteral("mkswap"), { deviceNode });
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
 
 bool linuxswap::resize(Report& report, const QString& deviceNode, qint64 length) const
 {
+    Q_UNUSED(length);
     const QString label = readLabel(deviceNode);
     const QString uuid = readUUID(deviceNode);
 
     QStringList args;
     if (!label.isEmpty())
-        args << QStringLiteral("-L") << label;
+        args << QStringLiteral("--label") << label;
     if (!uuid.isEmpty())
-        args << QStringLiteral("-U") << uuid;
+        args << QStringLiteral("--uuid") << uuid;
 
-    args << deviceNode << QString::number(length / 1024);
+    args << deviceNode;
 
     ExternalCommand cmd(report, QStringLiteral("mkswap"), args);
     return cmd.run(-1) && cmd.exitCode() == 0;
@@ -105,9 +107,9 @@ bool linuxswap::copy(Report& report, const QString& targetDeviceNode, const QStr
 
     QStringList args;
     if (!label.isEmpty())
-        args << QStringLiteral("-L") << label;
+        args << QStringLiteral("--label") << label;
     if (!uuid.isEmpty())
-        args << QStringLiteral("-U") << uuid;
+        args << QStringLiteral("--uuid") << uuid;
 
     args << targetDeviceNode;
 
@@ -117,7 +119,7 @@ bool linuxswap::copy(Report& report, const QString& targetDeviceNode, const QStr
 
 bool linuxswap::writeLabel(Report& report, const QString& deviceNode, const QString& newLabel)
 {
-    ExternalCommand cmd(report, QStringLiteral("mkswap"), QStringList() << QStringLiteral("-L") << newLabel << deviceNode);
+    ExternalCommand cmd(report, QStringLiteral("mkswap"), { QStringLiteral("--label"), newLabel, deviceNode });
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
 
@@ -131,15 +133,23 @@ QString linuxswap::unmountTitle() const
     return i18nc("@title:menu", "Deactivate swap");
 }
 
-bool linuxswap::mount(const QString& deviceNode)
+bool linuxswap::canMount(const QString& deviceNode, const QString& mountPoint) const {
+    Q_UNUSED(deviceNode);
+    // linux swap doesn't require mount point to activate
+    qDebug() << mountPoint;
+    return mountPoint != QStringLiteral("/");
+}
+
+bool linuxswap::mount(Report& report, const QString& deviceNode, const QString& mountPoint)
 {
-    ExternalCommand cmd(QStringLiteral("swapon"), QStringList() << deviceNode);
+    Q_UNUSED(mountPoint);
+    ExternalCommand cmd(report, QStringLiteral("swapon"), { deviceNode });
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
 
-bool linuxswap::unmount(const QString& deviceNode)
+bool linuxswap::unmount(Report& report, const QString& deviceNode)
 {
-    ExternalCommand cmd(QStringLiteral("swapoff"), QStringList() << deviceNode);
+    ExternalCommand cmd(report, QStringLiteral("swapoff"), { deviceNode });
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
 
@@ -149,7 +159,7 @@ bool linuxswap::updateUUID(Report& report, const QString& deviceNode) const
 
     QStringList args;
     if (!label.isEmpty())
-        args << QStringLiteral("-L") << label;
+        args << QStringLiteral("--label") << label;
 
     args << deviceNode;
 
