@@ -88,26 +88,33 @@ qint64 lvm2_pv::maxCapacity() const
 
 bool lvm2_pv::check(Report& report, const QString& deviceNode) const
 {
-    ExternalCommand cmd(report, QStringLiteral("lvm"), QStringList() << QStringLiteral("pvck") << QStringLiteral("-v") << deviceNode);
+    ExternalCommand cmd(report, QStringLiteral("lvm"), { QStringLiteral("pvck"), QStringLiteral("--verbose"), deviceNode });
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
 
 bool lvm2_pv::create(Report& report, const QString& deviceNode) const
 {
-    ExternalCommand cmd(report, QStringLiteral("lvm"), QStringList() << QStringLiteral("pvcreate") << deviceNode);
+    ExternalCommand cmd(report, QStringLiteral("lvm"), { QStringLiteral("pvcreate"), deviceNode });
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
 
 bool lvm2_pv::remove(Report& report, const QString& deviceNode) const
 {
 //      TODO: check if PV is a member of an exported VG
-    ExternalCommand cmd(report, QStringLiteral("lvm"), QStringList() << QStringLiteral("pvremove") << QStringLiteral("-ffy") << deviceNode);
+    ExternalCommand cmd(report, QStringLiteral("lvm"), { QStringLiteral("pvremove"), QStringLiteral("--force"), QStringLiteral("--force"), QStringLiteral("--yes"), deviceNode });
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
 
 bool lvm2_pv::updateUUID(Report& report, const QString& deviceNode) const
 {
-    ExternalCommand cmd(report, QStringLiteral("lvm"), QStringList() << QStringLiteral("pvchange") << QStringLiteral("-u") << deviceNode);
+    ExternalCommand cmd(report, QStringLiteral("lvm"), { QStringLiteral("pvchange"), QStringLiteral("--uuid"), deviceNode });
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
+
+bool lvm2_pv::canMount(const QString & deviceNode, const QString & mountPoint) const
+{
+    Q_UNUSED(deviceNode)
+    Q_UNUSED(mountPoint)
+    return false;
+}
 }
