@@ -21,8 +21,8 @@
 #include "util/capacity.h"
 #include "util/externalcommand.h"
 
+#include <QRegularExpression>
 #include <QStringList>
-#include <QRegExp>
 
 namespace FS
 {
@@ -42,9 +42,9 @@ reiser4::reiser4(qint64 firstsector, qint64 lastsector, qint64 sectorsused, cons
 void reiser4::init()
 {
     m_GetLabel = cmdSupportCore;
-    m_GetUsed = findExternal(QStringLiteral("debugfs.reiser4"), QStringList(), 16) ? cmdSupportFileSystem : cmdSupportNone;
-    m_Create = findExternal(QStringLiteral("mkfs.reiser4"), QStringList(), 16) ? cmdSupportFileSystem : cmdSupportNone;
-    m_Check = findExternal(QStringLiteral("fsck.reiser4"), QStringList(), 16) ? cmdSupportFileSystem : cmdSupportNone;
+    m_GetUsed = findExternal(QStringLiteral("debugfs.reiser4"), {}, 16) ? cmdSupportFileSystem : cmdSupportNone;
+    m_Create = findExternal(QStringLiteral("mkfs.reiser4"), {}, 16) ? cmdSupportFileSystem : cmdSupportNone;
+    m_Check = findExternal(QStringLiteral("fsck.reiser4"), {}, 16) ? cmdSupportFileSystem : cmdSupportNone;
     m_Move = m_Copy = (m_Check != cmdSupportNone) ? cmdSupportCore : cmdSupportNone;
     m_Backup = cmdSupportCore;
 }
@@ -85,26 +85,29 @@ qint64 reiser4::maxLabelLength() const
 
 qint64 reiser4::readUsedCapacity(const QString& deviceNode) const
 {
-    ExternalCommand cmd(QStringLiteral("debugfs.reiser4"), QStringList() << deviceNode);
+    ExternalCommand cmd(QStringLiteral("debugfs.reiser4"), { deviceNode });
 
-    if (cmd.run()) {
+    if (cmd.run(-1) && cmd.exitCode() == 16) {
         qint64 blocks = -1;
-        QRegExp rxBlocks(QStringLiteral("blocks:\\s+(\\d+)"));
+        QRegularExpression re(QStringLiteral("blocks:\\s+(\\d+)"));
+        QRegularExpressionMatch reBlocks = re.match(cmd.output());
 
-        if (rxBlocks.indexIn(cmd.output()) != -1)
-            blocks = rxBlocks.cap(1).toLongLong();
+        if (reBlocks.hasMatch())
+            blocks = reBlocks.captured(1).toLongLong();
 
         qint64 blockSize = -1;
-        QRegExp rxBlockSize(QStringLiteral("blksize:\\s+(\\d+)"));
+        re.setPattern(QStringLiteral("blksize:\\s+(\\d+)"));
+        QRegularExpressionMatch reBlockSize = re.match(cmd.output());
 
-        if (rxBlockSize.indexIn(cmd.output()) != -1)
-            blockSize = rxBlockSize.cap(1).toLongLong();
+        if (reBlockSize.hasMatch())
+            blockSize = reBlockSize.captured(1).toLongLong();
 
         qint64 freeBlocks = -1;
-        QRegExp rxFreeBlocks(QStringLiteral("free blocks:\\s+(\\d+)"));
+        re.setPattern(QStringLiteral("free blocks:\\s+(\\d+)"));
+        QRegularExpressionMatch reFreeBlocks = re.match(cmd.output());
 
-        if (rxFreeBlocks.indexIn(cmd.output()) != -1)
-            freeBlocks = rxFreeBlocks.cap(1).toLongLong();
+        if (reFreeBlocks.hasMatch())
+            freeBlocks = reFreeBlocks.captured(1).toLongLong();
 
         if (blocks > - 1 && blockSize > -1 && freeBlocks > -1)
             return (blocks - freeBlocks) * blockSize;
@@ -115,13 +118,13 @@ qint64 reiser4::readUsedCapacity(const QString& deviceNode) const
 
 bool reiser4::check(Report& report, const QString& deviceNode) const
 {
-    ExternalCommand cmd(report, QStringLiteral("fsck.reiser4"), QStringList() << QStringLiteral("--fix") << QStringLiteral("-y") << deviceNode);
+    ExternalCommand cmd(report, QStringLiteral("fsck.reiser4"), { QStringLiteral("--yes"), QStringLiteral("--fix"), deviceNode });
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
 
 bool reiser4::create(Report& report, const QString& deviceNode) const
 {
-    ExternalCommand cmd(report, QStringLiteral("mkfs.reiser4"), QStringList() << QStringLiteral("--yes") << deviceNode);
+    ExternalCommand cmd(report, QStringLiteral("mkfs.reiser4"), { QStringLiteral("--yes"), QStringLiteral("--force"), deviceNode });
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
 }
