@@ -142,7 +142,7 @@ bool CopyOperation::execute(Report& parent)
             // if we have overwritten a partition, reset device path and number
             if (overwrittenPartition()) {
                 copiedPartition().setDevicePath(overwrittenPartition()->devicePath());
-                copiedPartition().setPartitionPath(overwrittenPartition()->devicePath());
+                copiedPartition().setPartitionPath(overwrittenPartition()->partitionPath());
             }
 
             // now run the copy job itself
@@ -281,6 +281,9 @@ bool CopyOperation::canCopy(const Partition* p)
     if (p == nullptr)
         return false;
 
+    if (p->state() == Partition::StateNew && p->roles().has(PartitionRole::Luks))
+        return false;
+
     if (p->isMounted())
         return false;
 
