@@ -1,7 +1,7 @@
 /*************************************************************************
  *  Copyright (C) 2008-2012 by Volker Lanz <vl@fidra.de>                 *
+ *  Copyright (C) 2015-2016 by Teo Mrnjavac <teo@kde.org>                *
  *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
- *  Copyright (C) 2016 by Teo Mrnjavac <teo@kde.org>                     *
  *                                                                       *
  *  This program is free software; you can redistribute it and/or        *
  *  modify it under the terms of the GNU General Public License as       *
@@ -39,18 +39,19 @@
 #include "util/globallog.h"
 #include "util/helpers.h"
 
+#include <blkid/blkid.h>
+
+#include <QDebug>
 #include <QString>
 #include <QStringList>
-#include <QDebug>
 
 #include <KLocalizedString>
-#include <KIOCore/KMountPoint>
-#include <KIOCore/KDiskFreeSpaceInfo>
+#include <KMountPoint>
+#include <KDiskFreeSpaceInfo>
 #include <KPluginFactory>
 
 #include <parted/parted.h>
 #include <unistd.h>
-#include <blkid/blkid.h>
 
 K_PLUGIN_FACTORY_WITH_JSON(LibPartedBackendFactory, "pmlibpartedbackendplugin.json", registerPlugin<LibPartedBackend>();)
 
@@ -215,7 +216,7 @@ static void readSectorsUsed(PedDisk* pedDisk, const Device& d, Partition& p, con
 
     const KDiskFreeSpaceInfo freeSpaceInfo = KDiskFreeSpaceInfo::freeSpaceInfo(mountPoint);
 
-    if (p.isMounted() && freeSpaceInfo.isValid() && mountPoint != QStringLiteral())
+    if (p.isMounted() && freeSpaceInfo.isValid() && mountPoint != QString())
         p.fileSystem().setSectorsUsed(freeSpaceInfo.used() / d.logicalSectorSize());
     else if (p.fileSystem().supportGetUsed() == FileSystem::cmdSupportFileSystem)
         p.fileSystem().setSectorsUsed(p.fileSystem().readUsedCapacity(p.deviceNode()) / d.logicalSectorSize());
@@ -299,11 +300,10 @@ void LibPartedBackend::initFSSupport()
     try to determine the FileSystem usage, read the FileSystem label and store it all in newly created
     objects that are in the end added to the Device's PartitionTable.
 
-    @param pedDevice libparted pointer to the device
     @param d Device
     @param pedDisk libparted pointer to the partition table
 */
-void LibPartedBackend::scanDevicePartitions(PedDevice*, Device& d, PedDisk* pedDisk)
+void LibPartedBackend::scanDevicePartitions(Device& d, PedDisk* pedDisk)
 {
     Q_ASSERT(pedDisk);
     Q_ASSERT(d.partitionTable());
@@ -320,7 +320,12 @@ void LibPartedBackend::scanDevicePartitions(PedDevice*, Device& d, PedDisk* pedD
             continue;
 
         PartitionRole::Roles r = PartitionRole::None;
-        FileSystem::Type type = detectFileSystem(pedPartition);
+
+        char* pedPath = ped_partition_get_path(pedPartition);
+        FileSystem::Type type = FileSystem::Unknown;
+        if (pedPath)
+            type = detectFileSystem(QString::fromUtf8(pedPath));
+        free(pedPath);
 
         switch (pedPartition->type) {
         case PED_PARTITION_NORMAL:
@@ -352,18 +357,45 @@ void LibPartedBackend::scanDevicePartitions(PedDevice*, Device& d, PedDisk* pedD
 
         // libparted does not handle LUKS partitions
         QString mountPoint;
-        bool mounted;
-        if (fs->type() == FileSystem::Luks) {
-            mountPoint = FS::luks::mapperName(node);
-            mounted = (mountPoint != QString()) ? true : false;
+        bool mounted = false;
+        if (type == FileSystem::Luks) {
+            r |= PartitionRole::Luks;
+            FS::luks* luksFs = dynamic_cast<FS::luks*>(fs);
+            QString mapperNode = FS::luks::mapperName(node);
+            bool isCryptOpen = !mapperNode.isEmpty();
+            luksFs->setCryptOpen(isCryptOpen);
+            luksFs->setLogicalSectorSize(d.logicalSectorSize());
+
+            if (isCryptOpen) {
+                luksFs->loadInnerFileSystem(node, mapperNode);
+
+                mountPoint = mountPoints.findByDevice(mapperNode) ?
+                             mountPoints.findByDevice(mapperNode)->mountPoint() :
+                             QString();
+                // We cannot use libparted to check the mounted status because
+                // we don't have a PedPartition for the mapper device, so we use lsblk
+                mounted = isMounted(mapperNode);
+                if (mounted) {
+                    const KDiskFreeSpaceInfo freeSpaceInfo = KDiskFreeSpaceInfo::freeSpaceInfo(mountPoint);
+                    if (freeSpaceInfo.isValid() && mountPoint != QString())
+                        luksFs->setSectorsUsed(freeSpaceInfo.used() / d.logicalSectorSize() + luksFs->getPayloadOffset(node));
+                }
+            } else {
+                mounted = false;
+            }
+
+            luksFs->setMounted(mounted);
         } else {
-            mountPoint = mountPoints.findByDevice(node) ? mountPoints.findByDevice(node)->mountPoint() : QString();
+            mountPoint = mountPoints.findByDevice(node) ?
+                         mountPoints.findByDevice(node)->mountPoint() :
+                         QString();
             mounted = ped_partition_is_busy(pedPartition);
         }
 
         Partition* part = new Partition(parent, d, PartitionRole(r), fs, pedPartition->geom.start, pedPartition->geom.end, node, availableFlags(pedPartition), mountPoint, mounted, activeFlags(pedPartition));
 
-        readSectorsUsed(pedDisk, d, *part, mountPoint);
+        if (!part->roles().has(PartitionRole::Luks))
+            readSectorsUsed(pedDisk, d, *part, mountPoint);
 
         if (fs->supportGetLabel() != FileSystem::cmdSupportNone)
             fs->setLabel(fs->readLabel(part->deviceNode()));
@@ -381,7 +413,7 @@ void LibPartedBackend::scanDevicePartitions(PedDevice*, Device& d, PedDisk* pedD
         d.partitionTable()->setType(d, PartitionTable::msdos_sectorbased);
 
     foreach(const Partition * part, partitions)
-    PartitionAlignment::isAligned(d, *part);
+        PartitionAlignment::isAligned(d, *part);
 
     ped_disk_destroy(pedDisk);
 }
@@ -410,7 +442,7 @@ Device* LibPartedBackend::scanDevice(const QString& device_node)
         CoreBackend::setPartitionTableForDevice(*d, new PartitionTable(type, firstUsableSector(*d), lastUsableSector(*d)));
         CoreBackend::setPartitionTableMaxPrimaries(*d->partitionTable(), ped_disk_get_max_primary_partition_count(pedDisk));
 
-        scanDevicePartitions(pedDevice, *d, pedDisk);
+        scanDevicePartitions(*d, pedDisk);
     }
 
     return d;
@@ -448,6 +480,65 @@ QList<Device*> LibPartedBackend::scanDevices(bool excludeReadOnly)
     return result;
 }
 
+/** Detects the type of a FileSystem given a PedDevice and a PedPartition
+    @param partitionPath path to the partition
+    @return the detected FileSystem type (FileSystem::Unknown if not detected)
+*/
+FileSystem::Type LibPartedBackend::detectFileSystem(const QString& partitionPath)
+{
+    FileSystem::Type rval = FileSystem::Unknown;
+
+    blkid_cache cache;
+    if (blkid_get_cache(&cache, nullptr) == 0) {
+        blkid_dev dev;
+
+        if ((dev = blkid_get_dev(cache,
+                                 partitionPath.toLocal8Bit().constData(),
+                                 BLKID_DEV_NORMAL)) != nullptr) {
+            QString s = QString::fromUtf8(blkid_get_tag_value(cache,
+                                                              "TYPE",
+                                                              partitionPath.toLocal8Bit().constData()));
+
+            if (s == QStringLiteral("ext2")) rval = FileSystem::Ext2;
+            else if (s == QStringLiteral("ext3")) rval = FileSystem::Ext3;
+            else if (s.startsWith(QStringLiteral("ext4"))) rval = FileSystem::Ext4;
+            else if (s == QStringLiteral("swap")) rval = FileSystem::LinuxSwap;
+            else if (s == QStringLiteral("ntfs")) rval = FileSystem::Ntfs;
+            else if (s == QStringLiteral("reiserfs")) rval = FileSystem::ReiserFS;
+            else if (s == QStringLiteral("reiser4")) rval = FileSystem::Reiser4;
+            else if (s == QStringLiteral("xfs")) rval = FileSystem::Xfs;
+            else if (s == QStringLiteral("jfs")) rval = FileSystem::Jfs;
+            else if (s == QStringLiteral("hfs")) rval = FileSystem::Hfs;
+            else if (s == QStringLiteral("hfsplus")) rval = FileSystem::HfsPlus;
+            else if (s == QStringLiteral("ufs")) rval = FileSystem::Ufs;
+            else if (s == QStringLiteral("vfat")) {
+                // libblkid uses SEC_TYPE to distinguish between FAT16 and FAT32
+                QString st = QString::fromUtf8(blkid_get_tag_value(cache,
+                                                                   "SEC_TYPE",
+                                                                   partitionPath.toLocal8Bit().constData()));
+                if (st == QStringLiteral("msdos"))
+                    rval = FileSystem::Fat16;
+                else
+                    rval = FileSystem::Fat32;
+            } else if (s == QStringLiteral("btrfs")) rval = FileSystem::Btrfs;
+            else if (s == QStringLiteral("ocfs2")) rval = FileSystem::Ocfs2;
+            else if (s == QStringLiteral("zfs_member")) rval = FileSystem::Zfs;
+            else if (s == QStringLiteral("hpfs")) rval = FileSystem::Hpfs;
+            else if (s == QStringLiteral("crypto_LUKS")) rval = FileSystem::Luks;
+            else if (s == QStringLiteral("exfat")) rval = FileSystem::Exfat;
+            else if (s == QStringLiteral("nilfs2")) rval = FileSystem::Nilfs2;
+            else if (s == QStringLiteral("LVM2_member")) rval = FileSystem::Lvm2_PV;
+            else if (s == QStringLiteral("f2fs")) rval = FileSystem::F2fs;
+            else
+                qWarning() << "blkid: unknown file system type " << s << " on " << partitionPath;
+        }
+
+        blkid_put_cache(cache);
+    }
+
+    return rval;
+}
+
 CoreBackendDevice* LibPartedBackend::openDevice(const QString& device_node)
 {
     LibPartedDevice* device = new LibPartedDevice(device_node);
@@ -477,63 +568,6 @@ bool LibPartedBackend::closeDevice(CoreBackendDevice* core_device)
     return core_device->close();
 }
 
-/** Detects the type of a FileSystem given a PedDevice and a PedPartition
-    @param pedDevice pointer to the pedDevice. Must not be nullptr.
-    @param pedPartition pointer to the pedPartition. Must not be nullptr
-    @return the detected FileSystem type (FileSystem::Unknown if not detected)
-*/
-FileSystem::Type LibPartedBackend::detectFileSystem(PedPartition* pedPartition)
-{
-    FileSystem::Type rval = FileSystem::Unknown;
-
-    blkid_cache cache;
-    char* pedPath = nullptr;
-
-    if (blkid_get_cache(&cache, nullptr) == 0 && (pedPath = ped_partition_get_path(pedPartition))) {
-        blkid_dev dev;
-
-        if ((dev = blkid_get_dev(cache, pedPath, BLKID_DEV_NORMAL)) != nullptr) {
-            QString s = QString::fromUtf8(blkid_get_tag_value(cache, "TYPE", pedPath));
-            if (s == QStringLiteral("ext2")) rval = FileSystem::Ext2;
-            else if (s == QStringLiteral("ext3")) rval = FileSystem::Ext3;
-            else if (s.startsWith(QStringLiteral("ext4"))) rval = FileSystem::Ext4;
-            else if (s == QStringLiteral("swap")) rval = FileSystem::LinuxSwap;
-            else if (s == QStringLiteral("ntfs")) rval = FileSystem::Ntfs;
-            else if (s == QStringLiteral("reiserfs")) rval = FileSystem::ReiserFS;
-            else if (s == QStringLiteral("reiser4")) rval = FileSystem::Reiser4;
-            else if (s == QStringLiteral("xfs")) rval = FileSystem::Xfs;
-            else if (s == QStringLiteral("jfs")) rval = FileSystem::Jfs;
-            else if (s == QStringLiteral("hfs")) rval = FileSystem::Hfs;
-            else if (s == QStringLiteral("hfsplus")) rval = FileSystem::HfsPlus;
-            else if (s == QStringLiteral("ufs")) rval = FileSystem::Ufs;
-            else if (s == QStringLiteral("vfat")) {
-                // libblkid uses SEC_TYPE to distinguish between FAT16 and FAT32
-                QString st = QString::fromUtf8(blkid_get_tag_value(cache, "SEC_TYPE", pedPath));
-                if (st == QStringLiteral("msdos"))
-                    rval = FileSystem::Fat16;
-                else
-                    rval = FileSystem::Fat32;
-            } else if (s == QStringLiteral("btrfs")) rval = FileSystem::Btrfs;
-            else if (s == QStringLiteral("ocfs2")) rval = FileSystem::Ocfs2;
-            else if (s == QStringLiteral("zfs_member")) rval = FileSystem::Zfs;
-            else if (s == QStringLiteral("hpfs")) rval = FileSystem::Hpfs;
-            else if (s == QStringLiteral("crypto_LUKS")) rval = FileSystem::Luks;
-            else if (s == QStringLiteral("exfat")) rval = FileSystem::Exfat;
-            else if (s == QStringLiteral("nilfs2")) rval = FileSystem::Nilfs2;
-            else if (s == QStringLiteral("LVM2_member")) rval = FileSystem::Lvm2_PV;
-            else if (s == QStringLiteral("f2fs")) rval = FileSystem::F2fs;
-            else
-                qWarning() << "blkid: unknown file system type " << s << " on " << pedPath;
-        }
-
-        blkid_put_cache(cache);
-
-        free(pedPath);
-    }
-
-    return rval;
-}
-
 PedPartitionFlag LibPartedBackend::getPedFlag(PartitionTable::Flag flag)
 {
     for (quint32 i = 0; i < sizeof(flagmap) / sizeof(flagmap[0]); i++)
@@ -548,4 +582,5 @@ QString LibPartedBackend::lastPartedExceptionMessage()
     return s_lastPartedExceptionMessage;
 }
 
+
 #include "libpartedbackend.moc"
