@@ -67,20 +67,9 @@ bool LibPartedPartitionTable::commit(PedDisk* pd, quint32 timeout)
 
     bool rval = ped_disk_commit_to_dev(pd);
 
-    // The GParted authors have found a bug in libparted that causes it to intermittently
-    // not commit changes to the Linux kernel, probably a race. Until this is fixed in
-    // libparted, the following patch should help alleviate the consequences by just re-trying
-    // committing to the OS if it fails the first time after a short pause.
-    // See: http://git.gnome.org/browse/gparted/commit/?id=bf86fd3f9ceb0096dfe87a8c9a38403c13b13f00
-    if (rval) {
+    if (rval)
         rval = ped_disk_commit_to_os(pd);
 
-        if (!rval) {
-            sleep(1);
-            rval = ped_disk_commit_to_os(pd);
-        }
-    }
-
     if (!ExternalCommand(QStringLiteral("udevadm"), QStringList() << QStringLiteral("settle") << QStringLiteral("--timeout=") + QString::number(timeout)).run() &&
             !ExternalCommand(QStringLiteral("udevsettle"), QStringList() << QStringLiteral("--timeout=") + QString::number(timeout)).run())
         sleep(timeout);
@@ -123,7 +112,7 @@ static const struct {
     { FileSystem::Ntfs, QStringLiteral("ntfs") },
     { FileSystem::Exfat, QStringLiteral("ntfs") },
     { FileSystem::ReiserFS, QStringLiteral("reiserfs") },
-    { FileSystem::Reiser4, QStringLiteral("reiser4") },
+    { FileSystem::Reiser4, QStringLiteral("reiserfs") },
     { FileSystem::Xfs, QStringLiteral("xfs") },
     { FileSystem::Jfs, QStringLiteral("jfs") },
     { FileSystem::Hfs, QStringLiteral("hfs") },
@@ -252,7 +241,13 @@ bool LibPartedPartitionTable::clobberFileSystem(Report& report, const Partition&
         if (pedPartition->type == PED_PARTITION_NORMAL || pedPartition->type == PED_PARTITION_LOGICAL) {
             if (ped_device_open(pedDevice())) {
                 //reiser4 stores "ReIsEr4" at sector 128 with a sector size of 512 bytes
-                rval = ped_geometry_write(&pedPartition->geom, "0000000", 65536 / pedDevice()->sector_size, 1);
+
+                // We need to use memset instead of = {0} because clang sucks.
+                const long long zeroes_length = pedDevice()->sector_size*129;
+                char zeroes[zeroes_length];
+                memset(zeroes, 0, zeroes_length*sizeof(char));
+
+                rval = ped_geometry_write(&pedPartition->geom, zeroes, 0, 129);
 
                 if (!rval)
                     report.line() << xi18nc("@info/plain", "Failed to erase filesystem signature on partition <filename>%1</filename>.", partition.deviceNode());
@@ -309,14 +304,15 @@ FileSystem::Type LibPartedPartitionTable::detectFileSystemBySector(Report& repor
 {
     PedPartition* pedPartition = ped_disk_get_partition_by_sector(pedDisk(), sector);
 
-    FileSystem::Type rval = FileSystem::Unknown;
-
-    if (pedPartition)
-        rval = LibPartedBackend::detectFileSystem(pedPartition);
+    char* pedPath = ped_partition_get_path(pedPartition);
+    FileSystem::Type type = FileSystem::Unknown;
+    if (pedPartition && pedPath)
+        type = CoreBackendManager::self()->backend()->detectFileSystem(QString::fromUtf8(pedPath));
     else
         report.line() << xi18nc("@info/plain", "Could not determine file system of partition at sector %1 on device <filename>%2</filename>.", sector, device.deviceNode());
+    free(pedPath);
 
-    return rval;
+    return type;
 }
 
 bool LibPartedPartitionTable::setPartitionSystemType(Report& report, const Partition& partition)
